@@ -26,6 +26,8 @@
 #define _FB_H_
 
 #include <X11/X.h>
+#include <pixman/pixman.h>
+
 #include "scrnintstr.h"
 #include "pixmap.h"
 #include "pixmapstr.h"
@@ -607,16 +609,6 @@ extern int	fbGetWinPrivateIndex(void);
 extern const GCOps	fbGCOps;
 extern const GCFuncs	fbGCFuncs;
 
-#ifdef TEKX11
-#define FB_OLD_GC
-#define FB_OLD_SCREEN
-#endif
-
-#ifdef FB_OLD_SCREEN
-# define FB_OLD_MISCREENINIT	/* miScreenInit requires 14 args, not 13 */
-extern WindowPtr    *WindowTable;
-#endif
-
 #ifdef FB_24_32BIT
 #define FB_SCREEN_PRIVATE
 #endif
@@ -667,15 +659,6 @@ typedef struct {
 
 /* private field of GC */
 typedef struct {
-#ifdef FB_OLD_GC
-    unsigned char       pad1;
-    unsigned char       pad2;
-    unsigned char       pad3;
-    unsigned		fExpose:1;
-    unsigned		freeCompClip:1;
-    PixmapPtr		pRotatedPixmap;
-    RegionPtr		pCompositeClip;
-#endif    
     FbBits		and, xor;	/* reduced rop values */
     FbBits		bgand, bgxor;	/* for stipples */
     FbBits		fg, bg, pm;	/* expanded and filled */
@@ -688,17 +671,10 @@ typedef struct {
 #define fbGetGCPrivate(pGC)	((FbGCPrivPtr)\
 	(pGC)->devPrivates[fbGetGCPrivateIndex()].ptr)
 
-#ifdef FB_OLD_GC
-#define fbGetCompositeClip(pGC) (fbGetGCPrivate(pGC)->pCompositeClip)
-#define fbGetExpose(pGC)	(fbGetGCPrivate(pGC)->fExpose)
-#define fbGetFreeCompClip(pGC)	(fbGetGCPrivate(pGC)->freeCompClip)
-#define fbGetRotatedPixmap(pGC)	(fbGetGCPrivate(pGC)->pRotatedPixmap)
-#else
 #define fbGetCompositeClip(pGC) ((pGC)->pCompositeClip)
 #define fbGetExpose(pGC)	((pGC)->fExpose)
 #define fbGetFreeCompClip(pGC)	((pGC)->freeCompClip)
 #define fbGetRotatedPixmap(pGC)	((pGC)->pRotatedPixmap)
-#endif
 
 #define fbGetScreenPixmap(s)	((PixmapPtr) (s)->devPrivate)
 #ifdef FB_NO_WINDOW_PIXMAPS
@@ -773,12 +749,6 @@ typedef struct {
     ((pDrawable)->type == DRAWABLE_PIXMAP ? \
      TRUE : fbWindowEnabled((WindowPtr) pDrawable))
 
-#ifdef FB_OLD_SCREEN
-#define BitsPerPixel(d) (\
-    ((1 << PixmapWidthPaddingInfo[d].padBytesLog2) * 8 / \
-    (PixmapWidthPaddingInfo[d].padRoundUp+1)))
-#endif
-
 #define FbPowerOfTwo(w)	    (((w) & ((w) - 1)) == 0)
 /*
  * Accelerated tiles are power of 2 width <= FB_UNIT
@@ -1341,6 +1311,9 @@ fbCreateDefColormap(ScreenPtr pScreen);
 void
 fbClearVisualTypes(void);
 
+Bool
+fbHasVisualTypes (int depth);
+
 Bool
 fbSetVisualTypes (int depth, int visuals, int bitsPerRGB);
 
@@ -1785,13 +1758,11 @@ fbQueryBestSize (int class,
 		 unsigned short *width, unsigned short *height,
 		 ScreenPtr pScreen);
 
-#ifndef FB_OLD_SCREEN
 PixmapPtr
 _fbGetWindowPixmap (WindowPtr pWindow);
 
 void
 _fbSetWindowPixmap (WindowPtr pWindow, PixmapPtr pPixmap);
-#endif
 
 Bool
 fbSetupScreen(ScreenPtr	pScreen, 
@@ -2027,6 +1998,7 @@ fbEvenTile (FbBits	*dst,
 	    int		height,
 
 	    FbBits	*tile,
+	    FbStride	tileStride,
 	    int		tileHeight,
 
 	    int		alu,
@@ -2143,4 +2115,8 @@ void
 fbPaintWindow(WindowPtr pWin, RegionPtr pRegion, int what);
 
 
+pixman_image_t *image_from_pict (PicturePtr pict,
+				 Bool       has_clip);
+
 #endif /* _FB_H_ */
+
