@@ -1,6 +1,4 @@
 /*
- * $RCSId: xc/programs/Xserver/hw/kdrive/kdrive.c,v 1.29 2002/10/31 18:29:50 keithp Exp $ 
- *
  * Copyright © 1999 Keith Packard
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -97,7 +95,6 @@ extern WindowPtr *WindowTable;
 void
 KdSetRootClip (ScreenPtr pScreen, BOOL enable)
 {
-#ifndef FB_OLD_SCREEN
     WindowPtr	pWin = WindowTable[pScreen->myNum];
     WindowPtr	pChild;
     Bool	WasViewable;
@@ -224,7 +221,6 @@ KdSetRootClip (ScreenPtr pScreen, BOOL enable)
     }
     if (pWin->realized)
 	WindowsRestructured ();
-#endif	/* !FB_OLD_SCREEN */
 }
 
 void
@@ -1067,14 +1063,6 @@ KdScreenInit(int index, ScreenPtr pScreen, int argc, char **argv)
     pScreen->SaveScreen		= KdSaveScreen;
     pScreen->CreateWindow	= KdCreateWindow;
 
-#ifdef FB_OLD_SCREEN
-    pScreenPriv->BackingStoreFuncs.SaveAreas = fbSaveAreas;
-    pScreenPriv->BackingStoreFuncs.RestoreAreas = fbSaveAreas;
-    pScreenPriv->BackingStoreFuncs.SetClipmaskRgn = 0;
-    pScreenPriv->BackingStoreFuncs.GetImagePixmap = 0;
-    pScreenPriv->BackingStoreFuncs.GetSpansPixmap = 0;
-#endif
-
 #if KD_MAX_FB > 1
     if (screen->fb[1].depth)
     {
@@ -1156,12 +1144,8 @@ KdScreenInit(int index, ScreenPtr pScreen, int argc, char **argv)
     
 #if 0
     pScreen->backingStoreSupport = Always;
-#ifdef FB_OLD_SCREEN
-    miInitializeBackingStore (pScreen, &pScreenPriv->BackingStoreFuncs);
-#else
     miInitializeBackingStore (pScreen);
 #endif
-#endif
 
 
     /* 
