@@ -1,6 +1,4 @@
 /*
- * Id: kinput.c,v 1.1 1999/11/02 03:54:46 keithp Exp $
- *
  * Copyright  1999 Keith Packard
  * Copyright  2006 Nokia Corporation
  *
@@ -22,7 +20,6 @@
  * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  * PERFORMANCE OF THIS SOFTWARE.
  */
-/* $RCSId: xc/programs/Xserver/hw/kdrive/kinput.c,v 1.30 2002/11/13 16:37:39 keithp Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <kdrive-config.h>
@@ -42,7 +39,7 @@
 #endif
 
 #ifdef XKB
-#include <X11/extensions/XKBsrv.h>
+#include <xkbsrv.h>
 #endif
 
 #include <X11/extensions/XI.h>
@@ -740,6 +737,9 @@ KdKeyboardProc(DeviceIntPtr pDevice, int onoff)
     DevicePtr   pDev = (DevicePtr)pDevice;
     KdKeyboardInfo *ki;
     Atom xiclass;
+#ifdef XKB
+    XkbComponentNamesRec names;
+#endif
 
     if (!pDev)
 	return BadImplementation;
@@ -788,11 +788,9 @@ KdKeyboardProc(DeviceIntPtr pDevice, int onoff)
         KdInitModMap(ki);
         KdInitAutoRepeats(ki);
 
-#ifndef XKB
+#ifdef XKB
         if (!noXkbExtension) {
             memset(&names, 0, sizeof(XkbComponentNamesRec));
-            if (XkbInitialMap) 
-                names.keymap = XkbInitialMap;
 
             XkbSetRulesDflts ("base", "pc105", "us", NULL, NULL);
             ret = XkbInitKeyboardDeviceStruct (pDevice,
@@ -1915,11 +1913,6 @@ KdEnqueueKeyboardEvent(KdKeyboardInfo   *ki,
     KeybdCtrl *ctrl = NULL;
     int type, nEvents, i;
 
-#ifdef DEBUG
-    ErrorF("enqueuing kb event (scancode %d, %s)\n", scan_code, is_up ? "up" : "down");
-    ErrorF("event is from %s\n", ki->name);
-#endif
-    
     if (!ki || !ki->dixdev || !ki->dixdev->kbdfeed || !ki->dixdev->key)
 	return;
 
@@ -1947,9 +1940,6 @@ KdEnqueueKeyboardEvent(KdKeyboardInfo   *ki,
 	}
 	
         nEvents = GetKeyboardEvents(kdEvents, ki->dixdev, type, key_code);
-#ifdef DEBUG
-        ErrorF("KdEnqueueKeyboardEvent: got %d events from GKE\n", nEvents);
-#endif
         for (i = 0; i < nEvents; i++)
             KdQueueEvent(ki->dixdev, kdEvents + i);
     }
@@ -2009,12 +1999,6 @@ KdEnqueuePointerEvent(KdPointerInfo *pi, unsigned long flags, int rx, int ry,
     }
     z = rz;
 
-#ifdef DEBUG
-    ErrorF("sending motion notification for (%d, %d, %d)\n", x, y, z);
-    ErrorF("  comes from (%d, %d, %d)\n", rx, ry, rz);
-    ErrorF("  is %s\n", (flags & KD_MOUSE_DELTA) ? "relative" : "absolute");
-#endif
-
     if (flags & KD_MOUSE_DELTA)
         dixflags = POINTER_RELATIVE & POINTER_ACCELERATE;
     else
@@ -2028,9 +2012,6 @@ KdEnqueuePointerEvent(KdPointerInfo *pi, unsigned long flags, int rx, int ry,
          button <<= 1, n++) {
         if (((pi->buttonState & button) ^ (buttons & button)) &&
            !(buttons & button)) {
-#ifdef DEBUG
-            ErrorF("  posting button release %d\n", n);
-#endif
             _KdEnqueuePointerEvent(pi, ButtonRelease, x, y, z, n,
                                    dixflags, FALSE);
 	}
@@ -2039,9 +2020,6 @@ KdEnqueuePointerEvent(KdPointerInfo *pi, unsigned long flags, int rx, int ry,
          button <<= 1, n++) {
 	if (((pi->buttonState & button) ^ (buttons & button)) &&
 	    (buttons & button)) {
-#ifdef DEBUG
-            ErrorF("  posting button press %d\n", n);
-#endif
             _KdEnqueuePointerEvent(pi, ButtonPress, x, y, z, n,
                                    dixflags, FALSE);
         }
@@ -2057,11 +2035,6 @@ _KdEnqueuePointerEvent (KdPointerInfo *pi, int type, int x, int y, int z,
     int nEvents = 0, i = 0;
     int valuators[3] = { x, y, z };
 
-#ifdef DEBUG
-    ErrorF("mouse enqueuing event from device %s (%d, %d, %d; %d)\n",
-           pi->name, x, y, z, b);
-#endif
-
     /* TRUE from KdHandlePointerEvent, means 'we swallowed the event'. */
     if (!force && KdHandlePointerEvent(pi, type, x, y, z, b, absrel))
         return;
@@ -2321,6 +2294,7 @@ ChangeDeviceControl(register ClientPtr client, DeviceIntPtr pDev,
         return Success;
 
     case DEVICE_CORE:
+    case DEVICE_ENABLE:
         return Success;
 
     default:
@@ -2332,7 +2306,7 @@ ChangeDeviceControl(register ClientPtr client, DeviceIntPtr pDev,
 }
 
 int
-NewInputDeviceRequest(InputOption *options)
+NewInputDeviceRequest(InputOption *options, DeviceIntPtr *pdev)
 {
     InputOption *option = NULL;
     KdPointerInfo *pi = NULL;
@@ -2344,13 +2318,11 @@ NewInputDeviceRequest(InputOption *options)
                 pi = KdNewPointer();
                 if (!pi)
                     return BadAlloc;
-                pi->options = options;
             }
             else if (strcmp(option->value, "keyboard") == 0) {
                 ki = KdNewKeyboard();
                 if (!ki)
                     return BadAlloc;
-                ki->options = options;
             }
             else {
                 ErrorF("unrecognised device type!\n");
@@ -2359,8 +2331,19 @@ NewInputDeviceRequest(InputOption *options)
         }
     }
 
+    if (!ki && !pi) {
+        ErrorF("unrecognised device identifier!\n");
+        return BadValue;
+    }
+
     for (option = options; option; option = option->next) {
-        if (strcmp(option->key, "driver") == 0) {
+        if (strcmp(option->key, "device") == 0) {
+            if (pi && option->value)
+                pi->path = KdSaveString(option->value);
+            else if (ki && option->value)
+                ki->path = KdSaveString(option->value);
+        }
+        else if (strcmp(option->key, "driver") == 0) {
             if (pi) {
                 pi->driver = KdFindPointerDriver(option->value);
                 if (!pi->driver) {
@@ -2368,6 +2351,7 @@ NewInputDeviceRequest(InputOption *options)
                     KdFreePointer(pi);
                     return BadValue;
                 }
+                pi->options = options;
             }
             else if (ki) {
                 ki->driver = KdFindKeyboardDriver(option->value);
@@ -2376,6 +2360,7 @@ NewInputDeviceRequest(InputOption *options)
                     KdFreeKeyboard(ki);
                     return BadValue;
                 }
+                ki->options = options;
             }
         }
     }
@@ -2397,5 +2382,17 @@ NewInputDeviceRequest(InputOption *options)
         }
     }
 
+    if (pi) {
+        *pdev = pi->dixdev;
+    } else if(ki) {
+        *pdev = ki->dixdev;
+    }
+
     return Success;
 }
+
+void
+DeleteInputDeviceRequest(DeviceIntPtr pDev)
+{
+    RemoveDevice(pDev);
+}
